@@ -4,8 +4,8 @@ import pytest
 
 from dagster import (
     AssetKey,
+    AssetMaterialization,
     DagsterEventType,
-    Materialization,
     Output,
     execute_pipeline,
     pipeline,
@@ -52,27 +52,27 @@ def create_consolidated_sqlite_event_log_instance():
 
 
 asset_test = pytest.mark.parametrize(
-    'asset_aware_context',
+    "asset_aware_context",
     [create_in_memory_event_log_instance, create_consolidated_sqlite_event_log_instance,],
 )
 
 
 @solid
 def solid_one(_):
-    yield Materialization(label='one', asset_key=AssetKey('asset_1'))
+    yield AssetMaterialization(asset_key=AssetKey("asset_1"))
     yield Output(1)
 
 
 @solid
 def solid_two(_):
-    yield Materialization(label='two', asset_key=AssetKey('asset_2'))
-    yield Materialization(label='three', asset_key=AssetKey(['path', 'to', 'asset_3']))
+    yield AssetMaterialization(asset_key=AssetKey("asset_2"))
+    yield AssetMaterialization(asset_key=AssetKey(["path", "to", "asset_3"]))
     yield Output(1)
 
 
 @solid
 def solid_normalization(_):
-    yield Materialization(label='normalization', asset_key='path/to-asset_4')
+    yield AssetMaterialization(asset_key="path/to-asset_4")
     yield Output(1)
 
 
@@ -101,7 +101,7 @@ def test_asset_keys(asset_aware_context):
         asset_keys = event_log_storage.get_all_asset_keys()
         assert len(asset_keys) == 3
         assert set([asset_key.to_string() for asset_key in asset_keys]) == set(
-            ['asset_1', 'asset_2', 'path.to.asset_3']
+            ["asset_1", "asset_2", "path.to.asset_3"]
         )
 
 
@@ -111,7 +111,7 @@ def test_asset_events(asset_aware_context):
         instance, event_log_storage = ctx
         execute_pipeline(pipeline_one, instance=instance)
         execute_pipeline(pipeline_two, instance=instance)
-        asset_events = event_log_storage.get_asset_events(AssetKey('asset_1'))
+        asset_events = event_log_storage.get_asset_events(AssetKey("asset_1"))
         assert len(asset_events) == 2
         for event in asset_events:
             assert isinstance(event, EventRecord)
@@ -119,7 +119,7 @@ def test_asset_events(asset_aware_context):
             assert event.dagster_event.event_type == DagsterEventType.STEP_MATERIALIZATION
             assert event.dagster_event.asset_key
 
-        asset_events = event_log_storage.get_asset_events(AssetKey(['path', 'to', 'asset_3']))
+        asset_events = event_log_storage.get_asset_events(AssetKey(["path", "to", "asset_3"]))
         assert len(asset_events) == 1
 
 
@@ -129,7 +129,7 @@ def test_asset_run_ids(asset_aware_context):
         instance, event_log_storage = ctx
         one = execute_pipeline(pipeline_one, instance=instance)
         two = execute_pipeline(pipeline_two, instance=instance)
-        run_ids = event_log_storage.get_asset_run_ids(AssetKey('asset_1'))
+        run_ids = event_log_storage.get_asset_run_ids(AssetKey("asset_1"))
         assert set(run_ids) == set([one.run_id, two.run_id])
 
 
@@ -141,8 +141,8 @@ def test_asset_normalization(asset_aware_context):
         asset_keys = event_log_storage.get_all_asset_keys()
         assert len(asset_keys) == 1
         asset_key = asset_keys[0]
-        assert asset_key.to_string() == 'path.to.asset_4'
-        assert asset_key.path == ['path', 'to', 'asset_4']
+        assert asset_key.to_string() == "path.to.asset_4"
+        assert asset_key.path == ["path", "to", "asset_4"]
 
 
 @asset_test
@@ -163,6 +163,6 @@ def test_asset_wipe(asset_aware_context):
         execute_pipeline(pipeline_two, instance=instance)
         asset_keys = event_log_storage.get_all_asset_keys()
         assert len(asset_keys) == 3
-        instance.wipe_assets([AssetKey(['path', 'to', 'asset_3'])])
+        instance.wipe_assets([AssetKey(["path", "to", "asset_3"])])
         asset_keys = event_log_storage.get_all_asset_keys()
         assert len(asset_keys) == 2
